@@ -85,7 +85,7 @@ test_that("dimensions are correct", {
   expect_length(boot$ci, 2L)
   # dimensions of bootstrap replicates
   d_boot <- dim(boot$reps$t)
-  expect_identical(d_boot, c(as.integer(R), 5L))
+  expect_identical(d_boot, c(as.integer(R), 7L))
 
 })
 
@@ -111,10 +111,10 @@ test_that("output of coef() method has correct attributes", {
 test_that("coef() method returns correct values of coefficients", {
 
   # bootstrapped effects
-  expect_equivalent(coef(boot, parm = "a", type = "boot"), mean(boot$reps$t[, 2]))
-  expect_equivalent(coef(boot, parm = "b", type = "boot"), mean(boot$reps$t[, 3]))
-  expect_equivalent(coef(boot, parm = "c", type = "boot"), mean(boot$reps$t[, 4]))
-  expect_equivalent(coef(boot, parm = "c'", type = "boot"), mean(boot$reps$t[, 5]))
+  expect_equivalent(coef(boot, parm = "a", type = "boot"), mean(boot$reps$t[, 3]))
+  expect_equivalent(coef(boot, parm = "b", type = "boot"), mean(boot$reps$t[, 5]))
+  expect_equivalent(coef(boot, parm = "c", type = "boot"), mean(boot$reps$t[, 6]))
+  expect_equivalent(coef(boot, parm = "c'", type = "boot"), mean(boot$reps$t[, 7]))
   expect_equivalent(coef(boot, parm = "ab", type = "boot"), boot$ab)
 
   # effects computed on original sample
@@ -159,13 +159,13 @@ test_that("summary has correct structure", {
   expect_identical(summary_boot$object, boot)
   expect_identical(summary_theory$object, boot)
   # summary of the model fit
+  expect_s3_class(summary_boot$summary, "summary_cov_fit_mediation")
   expect_s3_class(summary_boot$summary, "summary_fit_mediation")
+  expect_s3_class(summary_theory$summary, "summary_cov_fit_mediation")
   expect_s3_class(summary_theory$summary, "summary_fit_mediation")
   # regression standard error for model y ~ m + x
-  expect_type(summary_boot$summary$s, "list")
-  expect_named(summary_boot$summary$s, "value")
-  expect_type(summary_theory$summary$s, "list")
-  expect_named(summary_theory$summary$s, "value")
+  expect_null(summary_boot$summary$s)
+  expect_null(summary_theory$summary$s)
   # R-squared for model y ~ m + x
   expect_null(summary_boot$summary$R2)
   expect_null(summary_theory$summary$R2)
@@ -184,15 +184,13 @@ test_that("attributes are correctly passed through summary", {
   expect_identical(summary_boot$summary$n, as.integer(n))
   expect_identical(summary_theory$summary$n, as.integer(n))
   # variable names
-  expect_identical(summary_boot$summary$variables, c("X", "Y", "M1"))
-  expect_null(summary_boot$summary$X)
-  expect_null(summary_boot$summary$Y)
-  expect_null(summary_boot$summary$M)
+  expect_identical(summary_boot$summary$x, "X")
+  expect_identical(summary_boot$summary$y, "Y")
+  expect_identical(summary_boot$summary$m, "M1")
   expect_null(summary_boot$summary$covariates)
-  expect_identical(summary_theory$summary$variables, c("X", "Y", "M1"))
-  expect_null(summary_theory$summary$X)
-  expect_null(summary_theory$summary$Y)
-  expect_null(summary_theory$summary$M)
+  expect_identical(summary_theory$summary$x, "X")
+  expect_identical(summary_theory$summary$y, "Y")
+  expect_identical(summary_theory$summary$m, "M1")
   expect_null(summary_theory$summary$covariates)
 
 })
@@ -227,9 +225,11 @@ test_that("effect summaries have correct names", {
   expect_identical(dim(summary_theory$summary$c_prime), c(1L, 4L))
   expect_identical(rownames(summary_theory$summary$c_prime), "X")
   expect_identical(colnames(summary_theory$summary$c_prime)[1], "Estimate")
-  # covariates
-  expect_null(summary_boot$summary$covariate_effects)
-  expect_null(summary_theory$summary$covariate_effects)
+  # no model fits
+  expect_null(summary_boot$summary$fit_mx)
+  expect_null(summary_boot$summary$fit_ymx)
+  expect_null(summary_theory$summary$fit_mx)
+  expect_null(summary_theory$summary$fit_ymx)
 
 })
 
@@ -246,10 +246,10 @@ test_that("effect summaries contain correct coefficient values", {
   expect_identical(summary_theory$summary$c_prime["X", "Estimate"], boot$fit$c_prime)
 
   # bootstrapped effects
-  expect_equal(summary_boot$summary$a["X", "Boot"], mean(boot$reps$t[, 2]))
-  expect_equal(summary_boot$summary$b["M1", "Boot"], mean(boot$reps$t[, 3]))
-  expect_equal(summary_boot$summary$c["X", "Boot"], mean(boot$reps$t[, 4]))
-  expect_equal(summary_boot$summary$c_prime["X", "Boot"], mean(boot$reps$t[, 5]))
+  expect_equal(summary_boot$summary$a["X", "Boot"], mean(boot$reps$t[, 3]))
+  expect_equal(summary_boot$summary$b["M1", "Boot"], mean(boot$reps$t[, 5]))
+  expect_equal(summary_boot$summary$c["X", "Boot"], mean(boot$reps$t[, 6]))
+  expect_equal(summary_boot$summary$c_prime["X", "Boot"], mean(boot$reps$t[, 7]))
 
 })
 
@@ -314,8 +314,8 @@ test_that("data returned by fortify() has correct attributes", {
 })
 
 
-## only implemented for simple mediation without covariates
-
+# ## only implemented for simple mediation without covariates
+#
 # test_that("covariates not implemented", {
 #
 #   # run test with regression method
