@@ -100,9 +100,11 @@ test_that("covariates not implemented", {
 
   # run regression fit
   set.seed(seed)
-  reg_fit <- fit_mediation(test_data, x = "X", y = "Y", m = "M1",
-                           covariates = c("C1", "C2"), method = "regression",
-                           robust = FALSE)
+  suppressWarnings(
+    reg_fit <- fit_mediation(test_data, x = "X", y = "Y", m = "M1",
+                             covariates = c("C1", "C2"), method = "regression",
+                             robust = FALSE)
+  )
 
   # try to run with covariates (should give warning)
   set.seed(seed)
@@ -122,8 +124,10 @@ test_that("multiple mediators not implemented", {
 
   # run regression fit
   set.seed(seed)
-  reg_fit <- fit_mediation(test_data, x = "X", y = "Y", m = c("M1", "M2"),
-                           method = "regression", robust = FALSE)
+  suppressWarnings(
+    reg_fit <- fit_mediation(test_data, x = "X", y = "Y", m = c("M1", "M2"),
+                             method = "regression", robust = FALSE)
+  )
 
   # try to run with multiple mediators (should give warning)
   set.seed(seed)
